@@ -6,6 +6,7 @@ from typing import Optional, List
 class Column:
     id: Optional[str] = field(default=None)
     title: Optional[str] = field(default=None)
+    type: Optional[str] = field(default=None)
 
 
 @dataclass
@@ -14,6 +15,7 @@ class ColumnValue:
     text: Optional[str] = field(default=None)
     type: Optional[str] = field(default=None)
     column: Optional[Column] = field(default=None)
+    display_value: Optional[str] = field(default=None)
 
 
 @dataclass
@@ -34,12 +36,46 @@ class Item:
     column_values: Optional[List[ColumnValue]] = field(default_factory=list)
 
 
+@dataclass
+class CreatedItem:
+    id: Optional[str] = field(default=None)
+
+
 @dataclass
 class User:
     name: Optional[str] = field(default=None)
     id: Optional[str] = field(default=None)
 
 
+@dataclass
+class Workspace:
+    name: Optional[str] = field(default=None)
+
+
+@dataclass
+class DocumentBlock:
+    type: Optional[str] = field(default=None)
+    content: Optional[str] = field(default=None)
+    position: Optional[int] = field(default=None)
+    updated_at: Optional[str] = field(default=None)
+
+
+@dataclass
+class Document:
+    id: Optional[str] = field(default=None)
+    created_at: Optional[str] = field(default=None)
+    created_by: Optional[User] = field(default=None)
+    doc_folder_id: Optional[str] = field(default=None)
+    doc_kind: Optional[str] = field(default=None)
+    name: Optional[str] = field(default=None)
+    url: Optional[str] = field(default=None)
+    workspace: Optional[Workspace] = field(default=None)
+    workspace_id: Optional[str] = field(default=None)
+    object_id: Optional[str] = field(default=None)
+    settings: Optional[str] = field(default=None)
+    blocks: Optional[List[DocumentBlock]] = field(default_factory=list)
+
+
 @dataclass
 class Update:
     id: Optional[str] = field(default=None)
@@ -75,10 +111,13 @@ class ActivityLog:
 
 @dataclass
 class Board:
+    id: Optional[str] = field(default=None)
     name: Optional[str] = field(default=None)
     items_page: Optional[ItemsPage] = field(default=None)
     updates: Optional[List[Update]] = field(default_factory=list)
     activity_logs: Optional[List[ActivityLog]] = field(default_factory=list)
+    columns: Optional[List[Column]] = field(default_factory=list)
+    groups: Optional[List[Group]] = field(default_factory=list)
 
 
 @dataclass
@@ -88,9 +127,11 @@ class Data:
     items: Optional[List[Item]] = field(default_factory=list)
     next_items_page: Optional[ItemsPage] = field(default=None)
     items_page_by_column_values: Optional[ItemsPage] = field(default=None)
+    create_item: Optional[CreatedItem] = field(default=None)
+    docs: Optional[List[Document]] = field(default_factory=list)
 
 
 @dataclass
 class MondayApiResponse:
     data: Data
-    account_id: int
+    account_id: int
\ No newline at end of file
